@@ -10,18 +10,27 @@ import sys
 
 if sys.version_info[0] < 3:
 	# Python 2.
+	unicode = unicode
 	string_types = (basestring,)
 
 	from itertools import izip_longest
 
-	def viewkeys(mapping):
-		return mapping.viewkeys()
+	def iterkeys(mapping):
+		return mapping.iterkeys()
 
 else:
 	# Python 3.
-	string_types = (str,)
+	unicode = str
+	string_types = (unicode,)
 
 	from itertools import zip_longest as izip_longest
 
-	def viewkeys(mapping):
+	def iterkeys(mapping):
 		return mapping.keys()
+
+try:
+	# Python 3.3+
+	import collections.abc as collections_abc
+except ImportError:
+	# Python 2.6 - 3.2
+	import collections as collections_abc
